@@ -22,7 +22,7 @@
 // for globals
 #include "globalostream.h"
 
-SpanDecorator::SpanDecorator( TextGenerator *t, CharTranslator *tr, char *ta) :
+SpanDecorator::SpanDecorator( TextGenerator *t, CharTranslator *tr, const string &ta) :
   TextDecorator( t, tr ), span(ta)
 {
 }
@@ -30,7 +30,7 @@ SpanDecorator::SpanDecorator( TextGenerator *t, CharTranslator *tr, char *ta) :
 void
 SpanDecorator::startDecorate()
 {
-  startTAG( span ) ;
+  startTAG( ) ;
 }
 
 void
@@ -40,7 +40,7 @@ SpanDecorator::endDecorate()
 }
 
 void
-SpanDecorator::startTAG( char *span ) const
+SpanDecorator::startTAG( ) const
 {
   (*sout) << "<span class=\"" << span << "\">" ;
 }
