@@ -29,9 +29,11 @@
 #include "colors.h"
 
 HtmlGeneratorFactory::HtmlGeneratorFactory(bool line_number, const string &t,
+                                           bool line_ref,
     const string &i, const string &h, const string &f, const string &c) :
-  GeneratorFactory (line_number, t), input_file_name (i), doc_header (h),
-    doc_footer (f), css_url (c)
+  GeneratorFactory (line_number, t, line_ref), 
+  input_file_name (i), doc_header (h),
+  doc_footer (f), css_url (c)
 {
 }
 
