@@ -27,17 +27,16 @@ using std::ostream;
 extern char *inputFileName ; /* what we're reading  */
 extern ostream* sout ;
 
-char *createOutputFileName( char *inputFileName ) ;
-void processFile( char *source_language, char *output_format,
-                  char *inputFileName, char *outputFileName,
-                  short entire_doc) ;
+void processFile( const char *source_language, const char *output_format,
+                  const char *inputFileName, const char *outputFileName,
+                  short entire_doc, bool gen_version) ;
 char *getCodeLine( void ) ;
 void generate( const char *s ) ;
 void generate( const char *s, int start, int end ) ;
 void generateln( const char *s ) ;
 void generate_preproc(const char *s);
 void generate_normal(const char *s);
-void generateNewLine() ;
+void generateNewLine(const char *s = 0) ;
 void generateTab() ;
 void generateComment( const char *s ) ;
 void generateString( const char *s ) ;
