@@ -28,8 +28,9 @@ bool LineNumberDecorator::generated_newline = true;
 unsigned int LineNumberDecorator::lineno = 1;
 
 LineNumberDecorator::LineNumberDecorator( TextGenerator *t, 
-                                          CharTranslator *c ) :
-  TextDecorator (t, c)
+                                          CharTranslator *c,
+                                          bool gen_ref ) :
+  TextDecorator (t, c), generate_ref (gen_ref)
 {
 }
 
@@ -38,8 +39,15 @@ LineNumberDecorator::generate_lineno()
 {
   if (generated_newline && line_num_digit > 0)
     {
+      if (generate_ref) // Oliver Fischer * plexus@snafu.de
+        (*sout) << "<a name=\"line" << lineno << "\">";
+
       (*sout) << std::setw (line_num_digit) << std::setfill ('0') 
               << lineno << ": ";
+
+      if (generate_ref)
+        (*sout) << "</a>";
+
       generated_newline = false;
     }
 }
