@@ -28,10 +28,12 @@ class LineNumberDecorator : public TextDecorator
   static bool generated_newline;
   static unsigned int lineno;
 
+  bool generate_ref;
+
   virtual void generate_lineno();
 
  public:
-  LineNumberDecorator( TextGenerator *, CharTranslator *);
+  LineNumberDecorator(TextGenerator *, CharTranslator *, bool gen_ref = false);
 
   virtual void generate( const char *s );
   virtual void generate_preproc(const char *s);
