@@ -46,21 +46,4 @@ class TextGenerator
   virtual void endText( const char *s );
 } ;
 
-// Decorator
-class TextDecorator : public TextGenerator
-{
- protected:
-  TextGenerator *decorated ;
-  
- public:
-  TextDecorator( TextGenerator *t, CharTranslator * );
-
-  virtual void startTextGeneration();
-  virtual void endTextGeneration();
-
-  // pure virtual functions
-  virtual void startDecorate() = 0 ;
-  virtual void endDecorate() = 0 ;
-} ;
-
 #endif
