@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999, 2000, 2001  Lorenzo Bettini, www.lorenzobettini.it 
+ * Copyright (C) 1999, 2000, 2001  Lorenzo Bettini, www.lorenzobettini.it
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,6 +35,7 @@
 #include "startapp.h"
 #include "copyright.h"
 #include "reportbugs.h"
+#include "parsetags.h"
 
 // FIXME:
 #include "htmlgeneratorfactory.h"
@@ -76,8 +77,6 @@ StartApp::StartApp() :
 {
 }
 
-extern int parseTags() ;
-
 int
 StartApp::start(int argc, char * argv[])
 {
@@ -160,8 +159,8 @@ StartApp::start(int argc, char * argv[])
   cssUrl = args_info.css_arg ;
   use_css = ( cssUrl != 0 ) ;
 
-  entire_doc = 
-    (! args_info.no_doc_given) && 
+  entire_doc =
+    (! args_info.no_doc_given) &&
     ( args_info.doc_given || (docTitle != 0) || use_css ||
       docHeader || docFooter ) ;
 
@@ -222,7 +221,7 @@ StartApp::start(int argc, char * argv[])
        {
          generator_factory =
            new CssGeneratorFactory (args_info.line_number_given,
-                                    title, args_info.line_number_ref_given, 
+                                    title, args_info.line_number_ref_given,
                                     input_name, doc_header,
                                     doc_footer, css_url);
        }
@@ -231,13 +230,13 @@ StartApp::start(int argc, char * argv[])
          if (format_xhtml && ! args_info.css_given)
            generator_factory =
              new XHtmlGeneratorFactory
-              (args_info.line_number_given, title, 
+              (args_info.line_number_given, title,
                args_info.line_number_ref_given, input_name, doc_header,
                doc_footer, css_url);
          else
            generator_factory =
             new HtmlGeneratorFactory
-             (args_info.line_number_given, title, 
+             (args_info.line_number_given, title,
               args_info.line_number_ref_given, input_name, doc_header,
               doc_footer, css_url);
        }
